package server

import (
	"encoding/json"
	"game/common/model/user"
	"game/common/proto/pb"
	"game/server/db/operation"
	"github.com/fox/fox/ipb"
	"github.com/fox/fox/log"
)

// 获取帐号
func (s *DbService) onGetUserAccount(iMsg *ipb.InternalMsg) *ipb.InternalMsg {
	s.operation(iMsg, func(us *user.UserAccount) (*user.UserAccount, pb.ErrCode) {
		return operation.NewUserAccountOp().GetUserAccount(us.Username)
	})
	return iMsg
}

// 创建帐号
func (s *DbService) onCreateUserAccount(iMsg *ipb.InternalMsg) *ipb.InternalMsg {
	s.operation(iMsg, operation.NewUserAccountOp().CreateUserAccount)
	return iMsg
}

// 修改密码
func (s *DbService) operation(iMsg *ipb.InternalMsg, operation func(us *user.UserAccount) (*user.UserAccount, pb.ErrCode)) {
	us := &user.UserAccount{}
	err := json.Unmarshal(iMsg.Msg, us)
	if err != nil {
		log.ErrorF("error unmarshalling user account %v", err)
		return
	}
	var code pb.ErrCode
	us, code = operation(us)
	if code != pb.ErrCode_OK {
		return
	}
	iMsg.Msg, err = json.Marshal(us)
	if err != nil {
		log.ErrorF("error marshalling user account %v", err)
		return
	}
	return
}

// 修改密码
func (s *DbService) onUpdateUserAccount(iMsg *ipb.InternalMsg) *ipb.InternalMsg {
	s.operation(iMsg, operation.NewUserAccountOp().UpdateUserPassword)
	return iMsg
}
