package server

import (
	"errors"
	"game/common/proto/pb"
	"game/server/login/model"
	"github.com/fox/fox/ipb"
	"github.com/fox/fox/processor"
	"github.com/fox/fox/service"
	"gorm.io/gorm"
)

func (s *LoginService) initProcessor() {
	s.processor.RegisterMessages(processor.RegisterMetas{
		pb.MsgId_C2SUserLoginId: {pb.C2SUserLogin{}, s.onLoginOrRegister},
	})
}

func (s *LoginService) checkLoginOrRegister(req *pb.C2SUserLogin) (user *model.UserAccount, code pb.ErrCode) {
	op := model.NewUserLoginOp()
	var err error
	user, err = op.Login(req.Username, req.Password, req.Ip, req.DeviceId)
	if err != nil {
		if errors.Is(err, gorm.ErrRecordNotFound) {
			user, err = op.RegisterNewUser(req.Username, req.Password, req.Ip, req.DeviceId)
			if err != nil {
				code = pb.ErrCode_RegisterUserExist
				return
			}
		} else if errors.Is(err, model.ErrUserOrPassword) {
			code = pb.ErrCode_LoginUserOrPwdErr
			return
		} else if errors.Is(err, model.ErrAccountFrozen) {
			code = pb.ErrCode_AccountFrozen
			return
		} else if errors.Is(err, model.ErrAccountBanned) {
			code = pb.ErrCode_AccountBanned
			return
		} else {
			code = pb.ErrCode_SystemErr
		}
	}
	return user, code
}

// 登录或注册
func (s *LoginService) onLoginOrRegister(iMsg *ipb.InternalMsg, req *pb.C2SUserLogin) {
	user, code := s.checkLoginOrRegister(req)
	userId := int64(0)
	rsp := &pb.S2CUserLogin{Code: code}
	if user != nil && code == pb.ErrCode_OK {
		rsp.UserId = int64(user.ID)
		rsp.Token = user.Password
		userId = rsp.UserId
	}
	s.SendServiceMsg(service.TopicEx(iMsg.ServiceName), iMsg.ConnId, userId, int32(pb.MsgId_S2CUserLoginId), rsp)
}
